@@ -11,7 +11,7 @@ from ratelimit import RateLimitException
 from bibchex.data import Suggestion
 from bibchex.problems import RetrievalProblem
 from bibchex.config import Config
-
+from bibchex.strutil import flexistrip
 
 TYPE_MAPPING = {
     'journal-article': ['article'],
@@ -70,7 +70,7 @@ class CrossrefSource(object):
            3: query by title
         """
         title = entry.data.get('title')
-        if not title:
+        if title is None:
             # Without a title, we're chanceless.
             self._ui.finish_subtask('CrossrefDOI')
             return None
@@ -90,11 +90,14 @@ class CrossrefSource(object):
         self._ui.finish_subtask('CrossrefDOI')
         if count > 0 and results:
             for i in range(0, min(10, count)):
+                if 'title' not in results[i] or 'DOI' not in results[i]:
+                    # Bogus data
+                    continue
                 suggested_title = results[i]['title']
                 doi = results[i]['DOI']
 
                 if not isinstance(suggested_title, list):
-                    suggested_title = [ suggested_title ]
+                    suggested_title = [suggested_title]
                 for possibility in suggested_title:
                     fuzz_score = fuzz.partial_ratio(title.lower(),
                                                     possibility.lower())
@@ -184,29 +187,29 @@ class CrossrefSource(object):
         btype = TYPE_MAPPING.get(data['type'])
         if not btype:
             self._ui.warn(
-                "Crossref", "Type {} not found in crossref source."
-                .format(data['type']))
+                "Crossref", "Type {} not found in crossref source. (Entry {})"
+                .format(data['type'], entry.get_id()))
         else:
             s.add_field('entrytype', btype)
 
         # Special handling for authors
         for author_data in data.get('author', []):
-            s.add_author(author_data.get('given', ""),
-                         author_data.get('family', ""))
+            s.add_author(author_data.get('given', "").strip(),
+                         author_data.get('family', "").strip())
 
         # Special handling for editors
         for editor_data in data.get('editor', []):
-            s.add_editor(editor_data.get('given', ""),
-                         editor_data.get('family', ""))
+            s.add_editor(editor_data.get('given', "").strip(),
+                         editor_data.get('family', "").strip())
 
         # Special handling for journal / book title
         if btype in ['journal-article', 'book-chapter']:
-            journal = data.get('container-title')
+            journal = flexistrip(data.get('container-title'))
             if journal:
                 s.add_field('journal', journal)
 
         # Special handling for URL. Only take it if it's not a DOI-Url
-        url = data.get('URL')
+        url = flexistrip(data.get('URL'))
         if url and (CrossrefSource.DOI_URL_RE.match(url) is None):
             s.add_field('url', url)
 
@@ -221,10 +224,8 @@ class CrossrefSource(object):
             if not field_to:
                 continue
 
-            if field_from == 'title':
-                pass  # TODO should we handle this?
             if field_from in data:
-                s.add_field(field_to, data[field_from])
+                s.add_field(field_to, flexistrip(data[field_from]))
 
         self._ui.finish_subtask('CrossrefQuery')
         return s
