@@ -95,3 +95,10 @@ class AbbrevFinder(object):
 
     def get(self):
         return self._pairs
+
+
+def flexistrip(s):
+    if isinstance(s, str):
+        return s.strip()
+    else:
+        return [st.strip for st in s]
